Trait AsField
trait AsField: crate::sealed::Sealed
Trait implemented to allow a type to be used as a field key.
Note: Although this is implemented for both theFieldtype and any type that can be borrowed as an&str, onlyFieldallows O(1) access. Indexing a field with a string results in an iterative search that performs string comparisons. Thus, if possible, once the key for a field is known, it should be used whenever possible.
Required Methods
fn as_field(self: &Self, metadata: &Metadata<'_>) -> Option<Field>Attempts to convert
&selfinto aFieldwith the specifiedmetadata.If
metadatadefines this field, then the field is returned. Otherwise, this returnsNone.