Struct Instrumented

struct Instrumented<T> { ... }

A Future that has been instrumented with a tracing Span.

This type is returned by the Instrument extension trait. See that trait's documentation for details.

Implementations

impl<T> Instrumented<T>

fn span(self: &Self) -> &Span

Borrows the Span that this type is instrumented by.

fn span_mut(self: &mut Self) -> &mut Span

Mutably borrows the Span that this type is instrumented by.

fn inner(self: &Self) -> &T

Borrows the wrapped type.

fn inner_mut(self: &mut Self) -> &mut T

Mutably borrows the wrapped type.

fn inner_pin_ref(self: Pin<&Self>) -> Pin<&T>

Get a pinned reference to the wrapped type.

fn inner_pin_mut(self: Pin<&mut Self>) -> Pin<&mut T>

Get a pinned mutable reference to the wrapped type.

fn into_inner(self: Self) -> T

Consumes the Instrumented, returning the wrapped type.

Note that this drops the span.

impl<'__pin, T> Unpin for Instrumented<T>

impl<F> IntoFuture for Instrumented<T>

fn into_future(self: Self) -> <F as IntoFuture>::IntoFuture

impl<T> Any for Instrumented<T>

fn type_id(self: &Self) -> TypeId

impl<T> Borrow for Instrumented<T>

fn borrow(self: &Self) -> &T

impl<T> BorrowMut for Instrumented<T>

fn borrow_mut(self: &mut Self) -> &mut T

impl<T> CloneToUninit for Instrumented<T>

unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)

impl<T> Drop for Instrumented<T>

fn drop(self: &mut Self)

impl<T> Freeze for Instrumented<T>

impl<T> From for Instrumented<T>

fn from(t: T) -> T

Returns the argument unchanged.

impl<T> Instrument for Instrumented<T>

impl<T> RefUnwindSafe for Instrumented<T>

impl<T> Send for Instrumented<T>

impl<T> Sync for Instrumented<T>

impl<T> ToOwned for Instrumented<T>

fn to_owned(self: &Self) -> T
fn clone_into(self: &Self, target: &mut T)

impl<T> UnsafeUnpin for Instrumented<T>

impl<T> UnwindSafe for Instrumented<T>

impl<T> WithSubscriber for Instrumented<T>

impl<T, U> Into for Instrumented<T>

fn into(self: Self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.

impl<T, U> TryFrom for Instrumented<T>

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

impl<T, U> TryInto for Instrumented<T>

fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>

impl<T: $crate::clone::Clone> Clone for Instrumented<T>

fn clone(self: &Self) -> Instrumented<T>

impl<T: $crate::fmt::Debug> Debug for Instrumented<T>

fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result

impl<T: Future> Future for Instrumented<T>

fn poll(self: Pin<&mut Self>, cx: &mut Context<'_>) -> Poll<<Self as >::Output>