Struct EnteredSpan
struct EnteredSpan { ... }
An owned version of Entered, a guard representing a span which has been
entered and is currently executing.
When the guard is dropped, the span will be exited.
This is returned by the Span::entered function.
Implementations
impl EnteredSpan
fn id(self: &Self) -> Option<Id>Returns this span's
Id, if it is enabled.fn exit(self: Self) -> SpanExits this span, returning the underlying
Span.
impl Debug for EnteredSpan
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Deref for EnteredSpan
fn deref(self: &Self) -> &Span
impl Drop for EnteredSpan
fn drop(self: &mut Self)
impl Freeze for EnteredSpan
impl RefUnwindSafe for EnteredSpan
impl Send for EnteredSpan
impl Sync for EnteredSpan
impl Unpin for EnteredSpan
impl UnsafeUnpin for EnteredSpan
impl UnwindSafe for EnteredSpan
impl<P, T> Receiver for EnteredSpan
impl<T> Any for EnteredSpan
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for EnteredSpan
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for EnteredSpan
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for EnteredSpan
fn from(t: T) -> TReturns the argument unchanged.
impl<T> Instrument for EnteredSpan
impl<T> WithSubscriber for EnteredSpan
impl<T, U> Into for EnteredSpan
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for EnteredSpan
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for EnteredSpan
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>