Trait AsId

trait AsId: crate::sealed::Sealed

Trait implemented by types which have a span Id.

Required Methods

fn as_id(self: &Self) -> Option<&Id>

Returns the Id of the span that self corresponds to, or None if this corresponds to a disabled span.