Function set_default
fn set_default<S>(subscriber: S) -> DefaultGuard
where
S: Subscriber + Send + Sync + 'static
Sets the Subscriber as the default for the current thread for the
duration of the lifetime of the returned DefaultGuard.
The default subscriber is used when creating a new Span or Event.