Function with_default
fn with_default<T, S, impl FnOnce() -> T: FnOnce() -> T>(subscriber: S, f: impl FnOnce() -> T) -> T
where
S: Subscriber + Send + Sync + 'static
Sets this Subscriber as the default for the current thread for the
duration of a closure.
The default subscriber is used when creating a new Span or
Event.